@@ -25,7 +25,7 @@
  *
  */
 /*
- * Copyright (c) 2002, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -310,8 +310,7 @@ SetUpConnectionSocket(int iport, void (*connectionFunc) (int))
 #else
     (void) ioctl(ConnectionSocket, FIOCLEX, 0);
 #endif
-    /* ultrix reads hang on Unix sockets, hpux reads fail */
-#if defined(O_NONBLOCK) && (!defined(ultrix) && !defined(hpux))
+#ifdef O_NONBLOCK
     (void) fcntl(ConnectionSocket, F_SETFL, O_NONBLOCK);
 #else
 #ifdef FIOSNBIO
