@@ -1,6 +1,6 @@
 /*
  * Copyright © 2001 Keith Packard, member of The XFree86 Project, Inc.
- * Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -80,9 +80,9 @@ RandrOldGetScreenInfo(FD fd, const unsigned char *buf)
 void
 RandrOldGetScreenInfoReply(FD fd, const unsigned char *buf)
 {
-    unsigned short nsize;
-    unsigned short nvg;
-    unsigned short ngvg;
+    // unsigned short nsize;
+    // unsigned short nvg;
+    // unsigned short ngvg;
 
     PrintField(RBf, 0, 1, REPLY, REPLYHEADER); /* RandrRequest reply */
     PrintField(RBf, 1, 1, RANDRREPLY, RANDRREPLYHEADER);
@@ -95,11 +95,11 @@ RandrOldGetScreenInfoReply(FD fd, const unsigned char *buf)
     PrintField(buf, 12, 4, TIMESTAMP, "timestamp");
     PrintField(buf, 16, 4, TIMESTAMP, "config-timestamp");
     PrintField(buf, 20, 2, CARD16, "num-visual-groups");
-    nvg = IShort(&buf[20]);
+    // nvg = IShort(&buf[20]);
     PrintField(buf, 22, 2, CARD16, "num-groups-of-visual-groups");
-    ngvg = IShort(&buf[22]);
+    // ngvg = IShort(&buf[22]);
     PrintField(buf, 24, 2, CARD16, "num-sizes");
-    nsize = IShort(&buf[24]);
+    // nsize = IShort(&buf[24]);
     PrintField(buf, 26, 2, CARD16, "size-id");
     PrintField(buf, 28, 2, CARD16, "visual-group-id");
     PrintField(buf, 30, 2, CARD16, "rotation");
