@@ -101,11 +101,13 @@ static void
 PrintSuccessfulAudioSetUpReply(const unsigned char *buf)
 {
     short v;
-    short n;
-    short m;
+    // short n;
+    // short m;
 
     if (NasVerbose < 1)
         return;
+        // m = IByte(&buf[28]);
+    // n = IByte(&buf[29]);
     PrintField(buf, 2, 2, CARD16, "protocol-major-version");
     PrintField(buf, 4, 2, CARD16, "protocol-minor-version");
     printfield(buf, 6, 2, DVALUE2(8 + 2 * n + (v + p + m) / 4),
@@ -119,9 +121,7 @@ PrintSuccessfulAudioSetUpReply(const unsigned char *buf)
     v = IShort(&buf[24]);
     printfield(buf, 26, 2, CARD16, "maximum-request-length");
     printfield(buf, 28, 1, CARD8, "max-tracks");
-    m = IByte(&buf[28]);
     printfield(buf, 29, 1, DVALUE1(n), "number of audio formats");
-    n = IByte(&buf[29]);
     PrintField(buf, 30, 1, CARD8, "number of element-types");
     PrintField(buf, 31, 1, CARD8, "number of wave-forms");
     PrintField(buf, 32, 1, CARD8, "number of actions");
@@ -138,6 +138,7 @@ PrintSuccessfulAudioSetUpReply(const unsigned char *buf)
 
 /* Error Printing procedures */
 
+#ifdef UNUSED
 static void
 AudioRequestError(const unsigned char *buf)
 {
@@ -227,6 +228,7 @@ AudioImplementationError(const unsigned char *buf)
     PrintField(buf, 8, 2, CARD16, "minor opcode");
     PrintField(buf, 10, 1, CARD8, "major opcode");
 }
+#endif
 
 /* ************************************************************ */
 /*								*/
@@ -323,7 +325,7 @@ AudioListDevices(const unsigned char *buf)
 void
 AudioListDevicesReply(const unsigned char *buf)
 {
-    long n;
+    // long n;
 
     PrintField(RBf, 0, 1, REPLY, REPLYHEADER); /* GetWindowAttributes */
     if (NasVerbose < 1)
@@ -332,7 +334,7 @@ AudioListDevicesReply(const unsigned char *buf)
     printfield(buf, 4, 4, CARD32, "reply length");
     printfield(buf, 8, 4, CARD32, "num devices");
 
-    n = ILong(&buf[8]);
+    // n = ILong(&buf[8]);
 }
 
 static long
@@ -351,7 +353,7 @@ AuString(const unsigned char *buf)
 static void
 AuDeviceAttributes(const unsigned char *buf)
 {
-    int l;
+    // int l;
 
     printfield(buf, 0, 4, CARD32, "value mask");
     printfield(buf, 4, 4, CARD32, "changeable mask");
@@ -362,7 +364,8 @@ AuDeviceAttributes(const unsigned char *buf)
     printfield(buf, 15, 1, CARD8, "num tracks");
     printfield(buf, 16, 4, CARD32, "access");
 
-    l = 20 + AuString(&buf[20]);
+    // l = 20 + AuString(&buf[20]);
+    (void)AuString(&buf[20]);
 }
 
 void
