@@ -25,7 +25,7 @@
  *
  */
 /*
- * Copyright (c) 2002, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2012, Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -199,7 +199,7 @@ CMDStringToInt(char *s, int *v)
     else if (*s == '0') {
         sscanf(s, "%o", v);
     }
-    else if (isdigit(*s)) {
+    else if (isdigit(*(unsigned char *)s)) {
         sscanf(s, "%d", v);
     }
     else if (*s == '\'') {
@@ -251,7 +251,7 @@ CMDSplitIntoWords(char *line, char **argv)
 
     argc = 0;
     while (*line) {
-        while (isspace(*line))
+        while (isspace(*(unsigned char *)line))
             line++;
         if (!*line)
             break;
@@ -267,7 +267,7 @@ CMDSplitIntoWords(char *line, char **argv)
         else {
             *argv++ = line;
             argc++;
-            while (*line && !isspace(*line))
+            while (*line && !isspace(*(unsigned char *)line))
                 line++;
             if (*line)
                 *line++ = '\0';
@@ -1138,6 +1138,9 @@ DataFromClient(FD fd)
     FDinfo[ServerFD].bufstart = 0;
 
     FlushFD(ServerFD);
+    if (FDinfo[ServerFD].buffer == NULL) /* connection closed in FlushFD */
+	return;
+
     /* also report the bytes to standard out */
     ReportFromClient(fd, FDinfo[ServerFD].buffer, n);
 }
@@ -1273,7 +1276,7 @@ ConnectToServer(Boolean report)
     if (port == ScopePort &&
         ((ServerHostName[0] == '\0') || strcmp(ServerHostName, ScopeHost) == 0))
     {
-        char error_message[100];
+        char error_message[300];
 
         snprintf(error_message, sizeof(error_message),
                  "Trying to attach to myself: %s,%d\n", ServerHostName, port);
@@ -1384,18 +1387,18 @@ DataFromRawFile(FD rawfd)
         /* If we already read a line last time, process it first,
            else get the next line for processing */
         if (FDinfo[rawfd].bufcount == 0) {
-            if (fgets(FDinfo[rawfd].buffer, BUFFER_SIZE, raw) == NULL) {
+            if (fgets((char *)FDinfo[rawfd].buffer, BUFFER_SIZE, raw) == NULL) {
                 CloseConnection(rawfd);
                 exit(0);
             }
-            FDinfo[rawfd].bufcount = strlen(FDinfo[rawfd].buffer);
+            FDinfo[rawfd].bufcount = strlen((char *)FDinfo[rawfd].buffer);
             debug(16, (stderr, "raw input = %s", FDinfo[rawfd].buffer));
         }
 
-        in = FDinfo[rawfd].buffer;
+        in = (char *)FDinfo[rawfd].buffer;
 
         /* lines starting with space indicate change of sender */
-        if (isspace(*in)) {
+        if (isspace(*(unsigned char *)in)) {
             /* If we already have data in buffer, process it */
             if ((fd != -1) && (FDinfo[fd].bufcount > 0)) {
                 debug(16, (stderr, "reporting %d bytes from: %s %s\n",
@@ -1413,7 +1416,7 @@ DataFromRawFile(FD rawfd)
             }
             else {
                 /* Need to parse header to figure out which direction */
-                while (isspace(*in)) {
+                while (isspace(*(unsigned char *)in)) {
                     in++;
                 }
                 if (strncmp(in, "Client Connect (fd ", 19) == 0) {
@@ -1448,7 +1451,7 @@ DataFromRawFile(FD rawfd)
                         int clientid;
 
                         in = n + 8;
-                        if (isdigit(*in))
+                        if (isdigit(*(unsigned char *)in))
                             clientid = strtol(in, NULL, 10);
                         else
                             clientid = 1;
@@ -1480,7 +1483,7 @@ DataFromRawFile(FD rawfd)
                     in = strstr(in, "(fd ");
                     if (in == NULL) {
                         warn("Did not find fd string in input entry");
-                        warn(FDinfo[rawfd].buffer);
+                        warn((char *)FDinfo[rawfd].buffer);
                         FDinfo[rawfd].bufcount = 0;
                         continue;
                     }
@@ -1500,7 +1503,7 @@ DataFromRawFile(FD rawfd)
                 n = strchr(in, ':');
                 if (n != NULL)
                     in = n + 1;
-                while (isspace(*in))
+                while (isspace(*(unsigned char *)in))
                     in++;
             }
         }
