@@ -25,7 +25,7 @@
  *
  */
 /*
- * Copyright (c) 2002, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2012, Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -1121,10 +1121,18 @@ PrintHOST(const unsigned char *buf)
     case 0:
     {
         struct in_addr ia;
+#ifdef HAVE_INET_NTOP
+        char addr[INET_ADDRSTRLEN] = "";
+#else
         char *addr;
+#endif
 
         memcpy(&ia, &buf[4], sizeof(ia));       /* Need to get alignment right */
+#ifdef HAVE_INET_NTOP
+        inet_ntop(AF_INET, &ia, addr, sizeof(addr));
+#else
         addr = inet_ntoa(ia);
+#endif
         PrintString8((unsigned char *) addr, strlen(addr), "address");
         break;
     }
@@ -1132,7 +1140,7 @@ PrintHOST(const unsigned char *buf)
     case 6:
     {
         struct in6_addr i6a;
-        char addr[INET6_ADDRSTRLEN];
+        char addr[INET6_ADDRSTRLEN] = "";
 
         memcpy(&i6a, &buf[4], sizeof(i6a));     /* Need to get alignment right */
         inet_ntop(AF_INET6, &i6a, addr, sizeof(addr));
