@@ -25,7 +25,7 @@
  *
  */
 /*
- * Copyright (c) 2002, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2023, Oracle and/or its affiliates.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -279,6 +279,12 @@
 #define CONNECTION	174
 #define SETofPROVIDER_CAPS 175
 
+#define DAMAGEREQUEST	176
+#define DAMAGEREPLY	177
+#define DAMAGEEVENT	178
+#define DAMAGEERROR	179
+#define DAMAGEREPORTLEVEL 180
+
 #define MaxTypes 256
 
 /* ************************************************************ */
@@ -332,7 +338,7 @@ extern struct TypeDef TD[MaxTypes];
 /*								*/
 /* ************************************************************ */
 
-/* declaration of the existance of print routines for the basic types */
+/* declaration of the existence of print routines for the basic types */
 
 extern int PrintINT8(const unsigned char *buf);
 extern int PrintINT16(const unsigned char *buf);
